
#include<stdio.h>
#include<unistd.h>
#include<sys/wait.h>
#include<netinet/in.h>
#include<string.h>
#include<stdlib.h>
#include<signal.h>
#include<pthread.h>

#include"sitar.h"
#include"sitar_com.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"
#include<file_comp/file_comp.h>

extern global_data_t gd;
extern pthread_mutex_t name_mutex;


int safe_exit(char * data) 
{
fprintf(stderr,"safe_exit(): *** Procces killd pgid=%d\n",gd.bf.my_pid);
fprintf(stderr,"safe_exit(): %s\n", data);

// pthread_mutex_lock(&name_mutex);
safe_pthread_mutex_lock(&name_mutex);
fprintf(stderr,"safe_exit(): return  %d = miname_dump(void);\n", miname_dump(gd.fi.midump_filename));
pthread_mutex_unlock(&name_mutex);

if(kill((gd.bf.my_pid * -1), SIGKILL)){
   fprintf(stderr,"safe_exit(): child process not killd GPID = %d\n", (gd.bf.my_pid * -1));
   fprintf(stderr,"safe_exit(): Please execute the following commands. \n");
   fprintf(stderr,"safe_exit(): # kill SIGKILL %d <enter>\n", (gd.bf.my_pid * -1));
   fprintf(stderr,"safe_exit(): or,\n");
   fprintf(stderr,"safe_exit(): # killall sitarctl; killall sitar_com; killall sitar_scan <enter>\n");
   } 

return 0;
}





